@@ -86,7 +86,7 @@ use constant {    ## no critic (ValuesAndExpressions::ProhibitConstantPragma, Na
   LOG_FORMAT              => qq{ %s [%s] %s\n },
 };
 
-our $VERSION = '1.1.6';
+our $VERSION = '1.1.7';
 
 our @EXPORT_OK = qw{ create_passkey };
 
@@ -373,7 +373,7 @@ sub get_creds_from_env {
     = qw{ AWS_ACCESS_KEY_ID AWS_SECRET_ACCESS_KEY AWS_SESSION_TOKEN };
 
   if ( $ENV{'AWS_ACCESS_KEY_ID'} && $ENV{'AWS_SECRET_ACCESS_KEY'} ) {
-    @{$creds}{@cred_keys} = ( 'ENV', @env_keys );
+    @{$creds}{@cred_keys} = ( 'ENV', @ENV{@env_keys} );
   }
 
   return $creds;
@@ -671,10 +671,13 @@ sub safe_dumper {
   elsif ( $self->get_insecure ) {
     $safe_rsp = Dumper [$obj];
 
-    $safe_rsp =~ s/^(.*)(access_?key[^']+)'([^']+)'([^']+)'/$1$2'$3'...'/gxsm;
     $safe_rsp
-      =~ s/^(.*)(secret_?access[^']+)'([^']+)'([^']+)'/$1$2'$3'...'/gxsm;
-    $safe_rsp =~ s/^(.*)(token[^']+)'([^']+)'([^']+)'/$1$2'$3'...'/gxsm;
+      =~ s/(.*?)(access_?key[^']+)'([^']+)'([^']+)'/$1$2'$3'...'/ixsmg;
+
+    $safe_rsp
+      =~ s/(.*?)(secret_?access[^']+)'([^']+)'([^']+)'/$1$2'$3'...'/ixsmg;
+
+    $safe_rsp =~ s/(.*?)(token[^']+)'([^']+)'([^']+)'/$1$2'$3'...'/ixsmg;
   } ## end elsif ( $self->get_insecure)
   else {
     $safe_rsp = '** configuration contents blocked by insecure setting **';
